import QtQuick 2.3
import QtQuick.Layouts 1.1
import Ubuntu.Components 1.1
import Ubuntu.Components.ListItems 1.0 as ListItem
import "GallerySRC"

MainView {
    applicationName: "com.ubuntu.developer.nik90.componentstore"
    useDeprecatedToolbar: false

    width: units.gu(120)
    height: units.gu(85)

    property var selectedWidget: null

    PageStack {
        id: stack

        Component.onCompleted: push(mainPage)

        Page {
            id: mainPage

            title: i18n.tr("Ubuntu Component Store Gallery")

            head {
                actions: [
                    Action {
                        iconName: "help"
                        text: i18n.tr("About")
                        onTriggered: stack.push(Qt.resolvedUrl("GallerySRC/About.qml"))
                    }
                ]
            }

            RowLayout {
                id: mainLayout

                anchors.fill: parent
                spacing: 0

                ListView {
                    id: widgetList
                    objectName: "widgetList"

                    clip: true
                    width: units.gu(40)
                    Layout.fillHeight: true

                    model: widgetsModel
                    delegate: ListItem.Standard {
                        text: model.label
                        enabled: model.source != ""
                        progression: true
                        selected: enabled && selectedWidget == model
                        onClicked: {
                            selectedWidget = model;
                        }
                    }
                }

                Rectangle {
                    color: "lightgrey"
                    width: units.gu(0.1)
                    Layout.fillHeight: true
                }

                Loader {
                    id: contentLoader
                    objectName: "contentLoader"

                    Layout.fillWidth: true
                    Layout.fillHeight: true

                    source: selectedWidget ? selectedWidget.source : ""
                }
            }
        }
    }

    WidgetsModel {
        id: widgetsModel
    }
}

